@@ -219,35 +219,19 @@ public class TabItem extends HBoxLayoutContainer {
 		List<ItemType> showableTypes = new ArrayList<ItemType>();
 		showableTypes.addAll(Arrays.asList(ItemType.values()));
 
-		/*
-		 * "application/zip", "application/x-zip",
-		 * "application/x-zip-compressed", "application/octet-stream",
-		 * "application/x-compress", "application/x-compressed",
-		 * "multipart/x-zip"
-		 */
-		// List<String> allowedMimeTypes =
-		// Arrays.asList("text/csv","text/plain","text/plain;
-		// charset=ISO-8859-1");
-
-		/**
-		 * "zip"
-		 */
-
-		/*
-		 * List<String> allowedFileExtensions = Arrays.asList("csv");
-		 * 
-		 * FilterCriteria filterCriteria = new FilterCriteria(allowedMimeTypes,
-		 * allowedFileExtensions, new HashMap<String, String>());
-		 */
+		
 		wselectDialog = new WorkspaceExplorerSelectDialog("Select CSV", false);
-		// filterCriteria, selectableTypes);
-
+		
 		WorskpaceExplorerSelectNotificationListener handler = new WorskpaceExplorerSelectNotificationListener() {
 
 			@Override
 			public void onSelectedItem(Item item) {
 
-				if (item.isFolder() || item.isRoot()) {
+				if (item == null || item.getType() == ItemType.FOLDER
+						|| item.getType() == ItemType.PRIVATE_FOLDER 
+						|| item.getType() == ItemType.SHARED_FOLDER
+						|| item.getType() == ItemType.VRE_FOLDER) {
+				
 					UtilsGXT3.info("Attention", "Select a valid csv!");
 
 				} else {
